/* YASS Utils: */

@import url('https://fonts.googleapis.com/css?family=Lato:400,400i,700,700i');
body {
    font-family: 'Lato', sans-serif;
}

.margin-top-10 {margin-top: 10px;}
.margin-bottom-10 {margin-bottom: 10px;}
.margin-left-10 {margin-left: 10px;}
.margin-right-10 {margin-right: 20px;}
.margin-top-20 {margin-top: 20px;}
.margin-bottom-20 {margin-bottom: 20px;}
.margin-left-20 {margin-left: 20px;}
.margin-right-20 {margin-right: 20px;}
.margin-top-40 {margin-top: 40px;}
.margin-bottom-40 {margin-bottom: 40px;}
.margin-left-40 {margin-left: 40px;}
.margin-right-40 {margin-right: 40px;}

.padding-top-10 {padding-top: 10px;}
.padding-bottom-10 {padding-bottom: 10px;}
.padding-left-10 {padding-left: 10px;}
.padding-right-10 {padding-right: 20px;}
.padding-top-20 {padding-top: 20px;}
.padding-bottom-20 {padding-bottom: 20px;}
.padding-left-20 {padding-left: 20px;}
.padding-right-20 {padding-right: 20px;}
.padding-top-40 {padding-top: 40px;}
.padding-bottom-40 {padding-bottom: 40px;}
.padding-left-40 {padding-left: 40px;}
.padding-right-40 {padding-right: 40px;}

/* Font awesome custom size */
.fa-6x {font-size: 6em;}
.fa-7x {font-size: 7em;}
.fa-8x {font-size: 8em;}
.fa-9x {font-size: 9em;}
.fa-10x {font-size: 10em;}